@@ -110,19 +110,19 @@ _free_meta_container_data (ContainerData * data)
   gst_structure_free (data->structure);
   g_hash_table_unref (data->static_items);
 
-  g_slice_free (ContainerData, data);
+  g_free (data);
 }
 
 static void
 _free_static_item (RegisteredMeta * item)
 {
-  g_slice_free (RegisteredMeta, item);
+  g_free (item);
 }
 
 static ContainerData *
 _create_container_data (GESMetaContainer * container)
 {
-  ContainerData *data = g_slice_new (ContainerData);
+  ContainerData *data = g_new (ContainerData, 1);
   data->structure = gst_structure_new_empty ("metadatas");
   data->static_items = g_hash_table_new_full (g_str_hash, g_str_equal,
       g_free, (GDestroyNotify) (GDestroyNotify) _free_static_item);
@@ -152,19 +152,21 @@ typedef struct
 } MetadataForeachData;
 
 static gboolean
-structure_foreach_wrapper (GQuark field_id, const GValue * value,
+structure_foreach_wrapper (const GstIdStr * fieldname, const GValue * value,
     gpointer user_data)
 {
   MetadataForeachData *data = (MetadataForeachData *) user_data;
 
-  data->func (data->container, g_quark_to_string (field_id), value, data->data);
+  data->func (data->container, gst_id_str_as_str (fieldname), value,
+      data->data);
   return TRUE;
 }
 
 static gboolean
-_append_foreach (GQuark field_id, const GValue * value, GESMetaContainer * self)
+_append_foreach (const GstIdStr * fieldname, const GValue * value,
+    GESMetaContainer * self)
 {
-  ges_meta_container_set_meta (self, g_quark_to_string (field_id), value);
+  ges_meta_container_set_meta (self, gst_id_str_as_str (fieldname), value);
 
   return TRUE;
 }
@@ -172,9 +174,9 @@ _append_foreach (GQuark field_id, const GValue * value, GESMetaContainer * self)
 /**
  * ges_meta_container_foreach:
  * @container: A #GESMetaContainer
- * @func: (scope call): A function to call on each of @container's set
- * metadata fields
- * @user_data: (closure): User data to send to @func
+ * @func: (scope call) (closure user_data): A function to call on each of
+ *    @container's set metadata fields
+* @user_data: User data to send to @func
  *
  * Calls the given function on each of the meta container's set metadata
  * fields.
@@ -195,8 +197,8 @@ ges_meta_container_foreach (GESMetaContainer * container,
   foreach_data.container = container;
   foreach_data.data = user_data;
 
-  gst_structure_foreach (structure,
-      (GstStructureForeachFunc) structure_foreach_wrapper, &foreach_data);
+  gst_structure_foreach_id_str (structure,
+      (GstStructureForeachIdStrFunc) structure_foreach_wrapper, &foreach_data);
 }
 
 static gboolean
@@ -216,7 +218,7 @@ _register_meta (GESMetaContainer * container, GESMetaFlag flags,
     return FALSE;
   }
 
-  static_item = g_slice_new0 (RegisteredMeta);
+  static_item = g_new0 (RegisteredMeta, 1);
   static_item->item_type = type;
   static_item->flags = flags;
   g_hash_table_insert (data->static_items, g_strdup (meta_item), static_item);
@@ -563,8 +565,8 @@ ges_meta_container_add_metas_from_string (GESMetaContainer * container,
     return FALSE;
   }
 
-  gst_structure_foreach (n_structure, (GstStructureForeachFunc) _append_foreach,
-      container);
+  gst_structure_foreach_id_str (n_structure,
+      (GstStructureForeachIdStrFunc) _append_foreach, container);
 
   gst_structure_free (n_structure);
   return TRUE;
