@@ -513,6 +513,7 @@ _set_property (GESProject * project, guint property_id,
 {
   switch (property_id) {
     case PROP_URI:
+      /* G_PARAM_CONSTRUCT_ONLY */
       GES_PROJECT_LOCK (project);
       project->priv->uri = g_value_dup_string (value);
       GES_PROJECT_UNLOCK (project);
@@ -540,7 +541,8 @@ ges_project_class_init (GESProjectClass * klass)
    * The location of the project to use.
    */
   _properties[PROP_URI] = g_param_spec_string ("uri", "URI",
-      "uri of the project", NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+      "uri of the project", NULL,
+      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, PROP_LAST, _properties);
 
