@@ -33,6 +33,10 @@
 #include "utils.h"
 #include "ges-launcher-kb.h"
 
+#ifdef HAVE_GST_VALIDATE
+#include <gst/validate/validate.h>
+#endif
+
 typedef enum
 {
   GST_PLAY_TRICK_MODE_NONE = 0,
@@ -321,6 +325,19 @@ _parse_track_type (const gchar * option_name, const gchar * value,
   return TRUE;
 }
 
+
+#ifdef HAVE_GST_VALIDATE
+static gboolean
+_parse_test_file (const gchar * option_name, const gchar * value,
+    GESLauncherParsedOptions * opts, GError ** error)
+{
+  opts->testfile = g_strdup (value);
+  gst_validate_init_debug ();
+  gst_validate_setup_test_file (opts->testfile, FALSE);
+  return TRUE;
+}
+#endif
+
 static gboolean
 _set_track_restriction_caps (GESTrack * track, const gchar * caps_str)
 {
@@ -618,10 +635,10 @@ _set_rendering_details (GESLauncher * self)
           smart_profile = TRUE;
         else {
           opts->format = get_file_extension (opts->outputuri);
-          prof = parse_encoding_profile (opts->format);
+          prof = gst_encoding_profile_from_string (opts->format);
         }
       } else {
-        prof = parse_encoding_profile (opts->format);
+        prof = gst_encoding_profile_from_string (opts->format);
         if (!prof) {
           ges_printerr ("Invalid format specified: %s", opts->format);
           goto done;
@@ -636,7 +653,7 @@ _set_rendering_details (GESLauncher * self)
 
         opts->format =
             g_strdup ("application/ogg:video/x-theora:audio/x-vorbis");
-        prof = parse_encoding_profile (opts->format);
+        prof = gst_encoding_profile_from_string (opts->format);
       }
 
       if (!prof) {
@@ -649,7 +666,8 @@ _set_rendering_details (GESLauncher * self)
         GstEncodingProfile *new_prof;
         GList *tmp;
 
-        if (!(new_prof = parse_encoding_profile (opts->container_profile))) {
+        if (!(new_prof =
+                gst_encoding_profile_from_string (opts->container_profile))) {
           ges_printerr ("Failed to parse container profile %s",
               opts->container_profile);
           gst_object_unref (prof);
@@ -671,12 +689,20 @@ _set_rendering_details (GESLauncher * self)
           goto done;
         }
 
-        for (tmp = (GList *)
-            gst_encoding_container_profile_get_profiles
-            (GST_ENCODING_CONTAINER_PROFILE (prof)); tmp; tmp = tmp->next) {
+        /* Existing profile is a single-elementary-stream profile, put it in the
+         * new target container profile */
+        if (!GST_IS_ENCODING_CONTAINER_PROFILE (prof)) {
           gst_encoding_container_profile_add_profile
               (GST_ENCODING_CONTAINER_PROFILE (new_prof),
-              GST_ENCODING_PROFILE (gst_encoding_profile_ref (tmp->data)));
+              GST_ENCODING_PROFILE (gst_encoding_profile_ref (prof)));
+        } else {
+          for (tmp = (GList *)
+              gst_encoding_container_profile_get_profiles
+              (GST_ENCODING_CONTAINER_PROFILE (prof)); tmp; tmp = tmp->next) {
+            gst_encoding_container_profile_add_profile
+                (GST_ENCODING_CONTAINER_PROFILE (new_prof),
+                GST_ENCODING_PROFILE (gst_encoding_profile_ref (tmp->data)));
+          }
         }
 
         gst_encoding_profile_unref (prof);
@@ -854,14 +880,19 @@ _project_loaded_cb (GESProject * project, GESTimeline * timeline,
   GESLauncherParsedOptions *opts = &self->priv->parsed_options;
   GST_INFO ("Project loaded, playing it");
 
-  if (opts->save_path) {
+  if (self->priv->seenerrors) {
+    return;
+  }
+
+  if (opts->save_path || opts->save_only_path) {
     gchar *uri;
     GError *error = NULL;
+    gchar *save_path = opts->save_path ? opts->save_path : opts->save_only_path;
 
     if (g_strcmp0 (opts->save_path, "+r") == 0) {
       uri = ges_project_get_uri (project);
-    } else if (!(uri = ensure_uri (opts->save_path))) {
-      g_error ("couldn't create uri for '%s", opts->save_path);
+    } else if (!(uri = ensure_uri (save_path))) {
+      g_error ("couldn't create uri for '%s", save_path);
 
       self->priv->seenerrors = TRUE;
       g_application_quit (G_APPLICATION (self));
@@ -877,6 +908,12 @@ _project_loaded_cb (GESProject * project, GESTimeline * timeline,
       g_error_free (error);
       g_application_quit (G_APPLICATION (self));
     }
+
+    if (opts->save_only_path) {
+      g_application_quit (G_APPLICATION (self));
+
+      return;
+    }
   }
 
   project_uri = ges_project_get_uri (project);
@@ -1028,6 +1065,8 @@ bus_message_cb (GstBus * bus, GstMessage * message, GESLauncher * self)
       break;
     }
     case GST_MESSAGE_EOS:
+      GST_DEBUG_BIN_TO_DOT_FILE_WITH_TS (GST_BIN (self->priv->pipeline),
+          GST_DEBUG_GRAPH_SHOW_ALL, "ges-launch.eos");
       if (!self->priv->parsed_options.ignore_eos) {
         ges_ok ("\nDone\n");
         g_application_quit (G_APPLICATION (self));
@@ -1168,7 +1207,8 @@ _run_pipeline (GESLauncher * self)
 
   bus = gst_pipeline_get_bus (GST_PIPELINE (self->priv->pipeline));
   gst_bus_add_signal_watch (bus);
-  g_signal_connect (bus, "message", G_CALLBACK (bus_message_cb), self);
+  g_signal_connect_object (bus, "message", G_CALLBACK (bus_message_cb), self,
+      0);
 
   g_application_hold (G_APPLICATION (self));
 
@@ -1424,7 +1464,7 @@ ges_launcher_parse_options (GESLauncher * self,
           "Specify the track restriction caps of the audio track.",
     },
 #ifdef HAVE_GST_VALIDATE
-    {"set-test-file", 0, 0, G_OPTION_ARG_STRING, &opts->testfile,
+    {"set-test-file", 0, 0, G_OPTION_ARG_CALLBACK, &_parse_test_file,
           "ges-launch-1.0 exposes gst-validate functionalities, such as test files and scenarios."
           " Scenarios describe actions to execute, such as seeks or setting of "
           "properties. "
@@ -1562,7 +1602,7 @@ _local_command_line (GApplication * application, gchar ** arguments[],
 
   if (opts->inspect_action_type) {
     ges_validate_print_action_types ((const gchar **) &((*arguments)[1]),
-        argc - 1);
+        g_strv_length (*arguments) - 1);
     goto done;
   }
 
@@ -1630,14 +1670,15 @@ keyboard_cb (const gchar * key_input, gpointer user_data)
     case 't':
       play_switch_trick_mode (self);
       break;
+    case '0':
+      play_do_seek (self, 0, self->priv->rate, self->priv->trick_mode);
+      break;
     case 27:                   /* ESC */
       if (key_input[1] == '\0') {
         g_application_quit (G_APPLICATION (self));
         break;
       }
-    case '0':
-      play_do_seek (self, 0, self->priv->rate, self->priv->trick_mode);
-      break;
+      /* FALLTHROUGH */
     default:
       if (strcmp (key_input, GST_PLAY_KB_ARROW_RIGHT) == 0) {
         relative_seek (self, +0.08);
@@ -1686,8 +1727,12 @@ _startup (GApplication * application)
   if (!_create_pipeline (self, opts->sanitized_timeline))
     goto failure;
 
-  if (opts->save_only_path)
+  if (opts->save_only_path) {
+    if (opts->load_path) {
+      g_application_hold (G_APPLICATION (self));
+    }
     goto done;
+  }
 
   if (!_set_playback_details (self))
     goto failure;
